
goog.provide('tyrion.ui.Login');

goog.require('goog.ui.Component');
goog.require('soy');
goog.require('tyrion.templates.login');


goog.scope(function() {
var _ = tyrion.ui;
var templates = tyrion.templates.login;
var dom = goog.dom;
var EventType = goog.events.EventType;



/**
 * Login form to enter the application main UI.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper to use.
 * @constructor
 * @extends {goog.ui.Component}
 */
_.Login = function(opt_domHelper) {
  goog.base(this, opt_domHelper);
};
goog.inherits(_.Login, goog.ui.Component);


/**
 * The email input of the login form.
 * @type {Element}
 * @private
 */
_.Login.prototype.emailInput_;


/**
 * The password input of the login form.
 * @type {Element}
 * @private
 */
_.Login.prototype.passwordInput_;


/**
 * The alert block to show error in the form.
 * @type {Element}
 * @private
 */
_.Login.prototype.alertBlock_;


/**
 * The login button.
 * @type {Element}
 * @private
 */
_.Login.prototype.loginButton_;


/**
 * The login animated GIF showed during the loading phase.
 * @type {Element}
 * @private
 */
_.Login.prototype.throbber_;


/** @inheritDoc */
_.Login.prototype.createDom = function() {
  var elem = soy.renderAsFragment(templates.form, null);
  this.setElementInternal(/** @type {Element} */ (elem));
};


/** @inheritDoc */
_.Login.prototype.disposeInternal = function() {
  goog.base(this, 'disposeInternal');

  this.emailInput_ = null;
  this.passwordInput_ = null;
  this.alertBlock_ = null;
  this.loginButton_ = null;
  this.throbber_ = null;
};


/** @inheritDoc */
_.Login.prototype.enterDocument = function() {
  goog.base(this, 'enterDocument');

  this.emailInput_ = this.dom_.getElement('email');
  this.passwordInput_ = this.dom_.getElement('password');
  this.alertBlock_ =
      dom.getElementsByTagNameAndClass('div', goog.getCssName('alert'),
          this.getElement())[0];
  this.loginButton_ =
      dom.getElementsByTagNameAndClass('button', null, this.getElement())[0];
  this.throbber_ =
      dom.getElementsByTagNameAndClass('img', null, this.getElement())[1];

  var form =
      dom.getElementsByTagNameAndClass('form', null, this.getElement())[0];
  this.getHandler().listen(form, EventType.SUBMIT, this.onSubmit_);
};


/** @inheritDoc */
_.Login.prototype.exitDocument = function() {
  goog.base(this, 'exitDocument');

  this.getHandler().removeAll();
};


/**
 * Called when the form it's send. It validates the data, and send it to the
 * local server for using it if correct.
 * @param {goog.events.Event} e The submit event.
 * @private
 */
_.Login.prototype.onSubmit_ = function(e) {
  e.preventDefault();

  var email = this.emailInput_.value;
  var password = this.passwordInput_.value;

  if (email == '' || password == '') {
    this.setError_('Introduce el email y la contraseña antes de continuar');
    return;
  }

  if (email.indexOf('@') == -1 || email.indexOf('.') == -1) {
    this.setError_('Introduce un email válido');
    return;
  }

  this.setError_('');

  this.emailInput_.disabled = true;
  this.passwordInput_.disabled = true;
  this.loginButton_.disabled = true;
  this.throbber_.style.display = '';
};


/**
 * Changes the error showed in the form.
 * @param {string} error The new error to show (empty to hide the message).
 * @private
 */
_.Login.prototype.setError_ = function(error) {
  if (error.length == 0) {
    this.alertBlock_.style.display = 'none';
  } else {
    this.alertBlock_.style.display = '';
    this.alertBlock_.innerHTML = error;
  }
};


});  // goog.scope
